==> pyrogen-0.3.5.dev2.tar.gz: pyrogen-0.3.5.dev2/README.md <==

<img src="https://raw.githubusercontent.com/Romuald78/pyrogen/master/doc/pyrogen.svg" width=128) />

This package is an Entity-Component-Based framework used to create 2D games.
<br>
*[...] TODO [...]*



[![Generic badge](https://img.shields.io/badge/pypi%20package-0.3.5.dev2-blue.svg)](https://pypi.org/project/pyrogen/)
[![Generic badge](https://img.shields.io/badge/python-3.6%20|%203.7%20|%203.8%20|%203.9-blue.svg)](https://www.python.org/downloads/)
[![Generic badge](https://img.shields.io/badge/license-MIT-blue.svg)](https://www.mit.edu/~amini/LICENSE.md)

[![Generic badge](https://img.shields.io/badge/repository-github.com-blue.svg)](https://github.com/Romuald78/pyrogen)
[![Generic badge](https://img.shields.io/badge/maintained-yes-green.svg)]()
[![Generic badge](https://img.shields.io/badge/status-in%20development-yellow.svg)]()
[![Generic badge](https://img.shields.io/badge/pull%20requests-welcome-green.svg)](https://github.com/Romuald78/pyrogen/pulls)

[![Generic badge](https://img.shields.io/badge/downloads-3/century-red.svg)]()



**Installation**

pyrogen is installable directly from Pypi:
```
pip install pyrogen
```



**Documentation**
<br>
*[...] TODO [...]*



**Code Examples / Tutorials**

If you want to run some demo scenes, just use the following command :
```
python -m pyrogen.demo [demoName]
```
<br>

*[...] TODO [...]*




**Community**

Wikipedia : <br>
Facebook  : <br>
Twitter   : <br>
[![Generic badge](https://img.shields.io/badge/discord-join-green.svg)](https://discord.gg/qMQnBztven)<br>
Website   : <br>

*[...] TODO [...]*



**Contact**

Romuald GRIGNON <br>
[romuald.grignon@gmail.com](mailto:romuald.grignon@gmail.com)

==> pyrogen-0.4.0.tar.gz: pyrogen-0.4.0/README.md <==

<img src="https://raw.githubusercontent.com/Romuald78/pyrogen/master/doc/pyrogen.svg" width=128) />

This package is an Entity-Component-Based framework used to create 2D games.
<br>
This is an early stage of development, but you can still check if the demo scene runs on your machine. If not, please don't hesitate to create an issue on the github page, joining all useful information such as the version you used, your machine configuration (OS, GPU, OpenGL Driver version), and also the full copy of the terminal output. If it runs, but slowly, please indicate the number of FPS you have (visible in the terminal output also).
<br>



[![Generic badge](https://img.shields.io/badge/pypi%20package-0.4.0-blue.svg)](https://pypi.org/project/pyrogen/)
[![Generic badge](https://img.shields.io/badge/python-3.6%20|%203.7%20|%203.8%20|%203.9-blue.svg)](https://www.python.org/downloads/)
[![Generic badge](https://img.shields.io/badge/license-MIT-blue.svg)](https://www.mit.edu/~amini/LICENSE.md)

[![Generic badge](https://img.shields.io/badge/repository-github.com-blue.svg)](https://github.com/Romuald78/pyrogen)
[![Generic badge](https://img.shields.io/badge/maintained-yes-green.svg)]()
[![Generic badge](https://img.shields.io/badge/status-in%20development-yellow.svg)]()
[![Generic badge](https://img.shields.io/badge/pull%20requests-welcome-green.svg)](https://github.com/Romuald78/pyrogen/pulls)

[![Generic badge](https://img.shields.io/badge/downloads-3/century-red.svg)]()



**Installation**

pyrogen is installable directly from Pypi:
```
pip install pyrogen
```



**Documentation**
Coming soon .... or not ^^
<br>



**Code Examples / Tutorials**

If you want to run the very first demo scene, just use the following command :
```
python -m pyrogen.tutorials.dev_test.dev_test
```




**Community**

Wikipedia : coming soon...<br>
Facebook  : coming soon...<br>
Twitter   : coming soon...<br>
[![Generic badge](https://img.shields.io/badge/discord-join-green.svg)](https://discord.gg/qMQnBztven)<br>
Website   : coming soon...<br>



**Contact**

Romuald GRIGNON <br>
[romuald.grignon@gmail.com](mailto:romuald.grignon@gmail.com)
